#!/usr/bin/python3
# coverage-builder tests
# (C) 2014 Canonical Ltd.
# Author: Allan LeSage <allan.lesage@canonical.com>
# License: GPL 3 or later

import os

from test import CoverageBuilderTestCase


class BuildTestCase(CoverageBuilderTestCase):

    def setUp(self):
        super(BuildTestCase, self).setUp()
        self._copy_dummy_project_into_place('cmake-project')

    def test_gcnos_appear(self):
        """dh_auto_build makes .gcno files appear."""
        # NOTE: find tests and assertions for configure elsewhere ;)
        self._call_dh_auto_configure()
        out, err = self._call_dh_auto_build()
        self.assertTrue(self._find_gcno())

    def test_warn_on_missing_gcno(self):
        """Helpful log message appears when not all .os produce .gcnos.

        Makefile remedy necessary, more common with ancient autotools
        process.

        """
        self._call_dh_auto_configure()
        # sneakily deposit an extra .o our Makefile doesn't know about
        open(os.path.join(self.pkgdir, 'impostor.o'), 'w').close()
        out, err = self._call_dh_auto_build()
        self.assertTrue(b'Warning: no .gcno found for ./impostor.o' in out)
