#!/usr/bin/python3
# coverage-builder tests
# (C) 2014 Canonical Ltd.
# Author: Allan LeSage <allan.lesage@canonical.com>
# License: GPL 3 or later

import os

from test import CoverageBuilderTestCase


class ConfigureTestCase(CoverageBuilderTestCase):

    def setUp(self):
        super(ConfigureTestCase, self).setUp()
        self._copy_dummy_project_into_place('cmake-project')

    def test_configure_enables_coverage_cmake_build_type(self):
        '''Diverted dh_auto_configure gets called with coverage.'''

        out, err = self._call_dh_auto_configure()
        self.assertTrue(
            b'Enabling coverage reporting per CMakeLists.txt CMAKE_BUILD_TYPE instruction.' in out)
        self.assertTrue(b'-- Coverage support enabled for targets: fibonacci' in out)

    def test_configure_enables_coverage_over_existing_cmake_build_type(self):
        '''Alternate CMAKE_BUILD_TYPE corrected to coverage.

        Typically set to 'Debug' in override_dh_auto_configure.
        '''
        # substitute a debian/rules with override_dh_auto_configure
        debian_rules_contents = """#!/usr/bin/make -f
%:
        dh $@

override_dh_auto_configure:
	dh_auto_configure -- -DCMAKE_BUILD_TYPE=Debug
"""
        with open(os.path.join(self.pkgdir, 'debian', 'rules'), 'w') as debian_rules:
            debian_rules.write(debian_rules_contents)
        out, err = self._call_dh_auto_configure()
        self.assertTrue(
            b'Enabling coverage reporting per CMakeLists.txt CMAKE_BUILD_TYPE instruction.' in out)
        self.assertTrue(b'-- Coverage support enabled for targets: fibonacci' in out)

    def test_configure_enables_coverage_over_existing_blank_cmake_build_type(self):
        '''Alternate *blank* CMAKE_BUILD_TYPE corrected to coverage.

        A few builds do this in override_dh_auto_configure, evidently
        to unset Debug or some such.
        '''

        # substitute a debian/rules with override_dh_auto_configure
        debian_rules_contents = """#!/usr/bin/make -f
%:
        dh $@

override_dh_auto_configure:
	dh_auto_configure -- -DCMAKE_BUILD_TYPE=
"""
        with open(os.path.join(self.pkgdir, 'debian', 'rules'), 'w') as debian_rules:
            debian_rules.write(debian_rules_contents)
        out, err = self._call_dh_auto_configure()
        self.assertTrue(
            b'Enabling coverage reporting per CMakeLists.txt CMAKE_BUILD_TYPE instruction.' in out)
        self.assertTrue(b'-- Coverage support enabled for targets: fibonacci' in out)
