#!/usr/bin/python3
# coverage-builder tests
# (C) 2014 Canonical Ltd.
# Author: Allan LeSage <allan.lesage@canonical.com>
# License: GPL 3 or later

import os
import xml.etree.ElementTree as etree

from test import CoverageBuilderTestCase, snip_coverage_xml


class TestTestCase(CoverageBuilderTestCase):

    def setUp(self):
        super(TestTestCase, self).setUp()
        self._copy_dummy_project_into_place('cmake-project')

    def test_test(self):
        """dh_auto_test generates a coverage.xml.

        If we're able to parse the XML and verify the line rate we're
        in good shape.
        """
        self._call_dh_auto_configure()
        self._call_dh_auto_build()
        out, err = self._call_dh_auto_test()
        coverage_xml = snip_coverage_xml(out.decode())
        root = etree.fromstring(coverage_xml)
        node = root.find(".//*[@filename='fibonacci.cpp']")
        self.assertEqual(1.0, float(node.attrib['line-rate']))

    def test_fifty_percent_coverage(self):
        """Accurate line coverage for a less thorough test suite."""
        test_fibonacci_cpp_contents = """
#include "gtest/gtest.h"
#include "fibonacci.h"

TEST(FibonacciTest, FirstTermIsCorrect) {
  EXPECT_EQ(0, fib(0));
}
"""
        with open(os.path.join(self.pkgdir,
                               'tests',
                               'test_fibonacci.cpp'),
                  'w') as test_fibonacci_cpp:
            test_fibonacci_cpp.write(test_fibonacci_cpp_contents)
        self._call_dh_auto_configure()
        self._call_dh_auto_build()
        out, err = self._call_dh_auto_test()
        coverage_xml = snip_coverage_xml(out.decode())
        root = etree.fromstring(coverage_xml)
        node = root.find(".//*[@filename='fibonacci.cpp']")
        self.assertAlmostEqual(0.5, float(node.attrib['line-rate']))
